@@ -16,7 +16,8 @@ from .compat import basestring, is_py2
 
 class TimeConvert:
     def __init__(self, timezone=None, format=None):
-        self.BASE_TIME_ZONE = tzlocal.get_localzone().zone
+        tz_localzone = tzlocal.get_localzone()
+        self.BASE_TIME_ZONE = tz_localzone.zone if hasattr(tz_localzone, 'zone') else tz_localzone.key
         self.DATETIME_FORMAT = '%Y-%m-%d %H:%M:%S'
         self.DATE_FORMAT = '%Y-%m-%d'
         self.WEEK_FORMAT = '%W'
@@ -33,6 +34,9 @@ class TimeConvert:
     def format(self, format=None):
         return format or self.TIME_FORMAT
 
+    def date_format(self, format=None):
+        return format or self.DATE_FORMAT
+
     # PRIVATE
 
     def __utc_datetime(self, utc_dt=None, timezone=None, years=0, months=0, days=0, seconds=0, microseconds=0, milliseconds=0, minutes=0, hours=0, weeks=0):
@@ -146,7 +150,8 @@ class TimeConvert:
         return self.datetime_to_date(self.local_datetime(dt=dt, utc=utc, ms=ms, timezone=timezone, years=years, months=months, days=days, seconds=seconds, microseconds=microseconds, milliseconds=milliseconds, minutes=minutes, hours=hours, weeks=weeks))
 
     def datetime_to_date(self, dt):
-        return datetime.datetime.date(dt)
+        # return datetime.datetime.date(dt)
+        return dt.date()
 
     def is_the_same_day(self, dt1, dt2):
         return self.local_string(dt1, format=self.DATE_FORMAT) == self.local_string(dt2, format=self.DATE_FORMAT)
@@ -292,6 +297,38 @@ class TimeConvert:
     def seconds_to_milliseconds(self, s):
         return self.__seconds_to_other(s, base=self.SECOND_MILLISECOND)
 
+    # STRING ==> DATE
+
+    def string_to_date(self, string, format=None):
+        format = self.date_format(format)
+        if not self.validate_string(string, format):
+            return None
+        return self.string_to_datetime(string, format).date()
+
+    def string_to_utc_date(self, string, format=None):
+        format = self.date_format(format)
+        if not self.validate_string(string, format):
+            return None
+        return self.string_to_utc_datetime(string, format).date()
+
+    def string_to_local_date(self, string, format=None):
+        format = self.date_format(format)
+        if not self.validate_string(string, format):
+            return None
+        return self.string_to_local_datetime(string, format).date()
+
+    def utc_string_to_utc_date(self, utc_string, format=None):
+        format = self.date_format(format)
+        if not self.validate_string(utc_string, format):
+            return None
+        return self.utc_string_to_utc_datetime(utc_string, format).date()
+
+    def utc_string_to_local_date(self, utc_string, format=None):
+        format = self.date_format(format)
+        if not self.validate_string(utc_string, format):
+            return None
+        return self.utc_string_to_local_datetime(utc_string, format).date()
+
     # STRING ==> DATETIME
 
     def string_to_datetime(self, string, format=None):
@@ -552,5 +589,17 @@ class TimeConvert:
             return td.days * 86400 + td.seconds
         return ((td.days * 86400 + td.seconds) * self.SECOND_MICROSECOND + td.microseconds) / self.SECOND_MICROSECOND
 
+    def date_range(self, start_date, end_date, include_end=None):
+        if isinstance(start_date, str):
+            start_date = datetime.datetime.strptime(start_date, '%Y-%m-%d').date()
+        if isinstance(end_date, str):
+            end_date = datetime.datetime.strptime(end_date, '%Y-%m-%d').date()
+        if include_end:
+            end_date = end_date + datetime.timedelta(1)
+        for n in range(int((end_date - start_date).days)):
+            yield start_date + datetime.timedelta(n)
+
+    daterange = date_range
+
 
 TimeConvert = TimeConvert()
